#!/usr/bin/env bash
#
# Usage: create_resource.sh <oci-cluster-id> <config-file-full-path> <pem-file-full-path> <namespace>
#

readonly OCI_CLUSTER_ID=$1
readonly CONFIG_FILE_FULL_NAME=$2
readonly PEM_FILE_FULL_NAME=$3
readonly NAMESPACE=$4
DOCKER_USERNAME=${DOCKER_USERNAME:-"elotlcustomer"}
DOCKER_PASSWORD=${DOCKER_PASSWORD:-"dckr_pat_JdEJznSejD8rkMPkAIn-14BpE9k"}
readonly DOCKER_SECRET_NAME="dockerhub"
readonly OCI_SECRET_NAME="oci-config"

function create_namespace_if_not_exist() {
  kubectl create namespace "$NAMESPACE" --dry-run=client -o yaml | kubectl apply -f -
}

function create_docker_secret_if_not_exist() {
  kubectl create secret docker-registry -n "$NAMESPACE" "$DOCKER_SECRET_NAME" \
    --docker-server=docker.io \
    --docker-username="$DOCKER_USERNAME" \
    --docker-password="$DOCKER_PASSWORD" \
    --dry-run=client -o yaml | kubectl apply -f -
}

function create_oci_secret_if_not_exist() {
  kubectl create secret generic -n "$NAMESPACE" "$OCI_SECRET_NAME" \
    --from-file="$CONFIG_FILE_FULL_NAME" \
    --from-file="$PEM_FILE_FULL_NAME" \
    --dry-run=client -o yaml | kubectl apply -f -
}

create_namespace_if_not_exist
create_docker_secret_if_not_exist
create_oci_secret_if_not_exist

readonly helm_values="./${OCI_CLUSTER_ID}_values.yaml"

cat <<EOF >"$helm_values"
clusterID: ${OCI_CLUSTER_ID}
cloudProvider: oci
oci:
  configFile: ${CONFIG_FILE_FULL_NAME}
  pemFile: ${PEM_FILE_FULL_NAME}
imagePullSecretName: ${DOCKER_SECRET_NAME}
labels: "elotl-luna=true"
EOF
